<?php
/**
 * Redux Framework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * any later version.
 *
 * Redux Framework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Redux Framework. If not, see <http://www.gnu.org/licenses/>.
 *
 * @package     ReduxFramework
 * @author      Dovy Paukstys (dovy)
 * @version     3.0.0
 */
// Exit if accessed directly
if (!defined('ABSPATH'))
    exit;

// Don't duplicate me!
if (!class_exists('ReduxFramework_extension_custom_font')) {
    
    
    /**
     * Main ReduxFramework custom_field extension class
     *
     * @since       3.1.6
     */
    class ReduxFramework_extension_custom_font /* extends ReduxFramework */ 
    {
        // Protected vars
        protected $parent;
        public $extension_url;
        public $upload_dir;
        public $upload_dir_url;
        /* @var $theInstance ReduxFramework_extension_custom_font */
        public static $theInstance;
        public $validate_class = "font_load";
        
        /**
         * Array of values
         * @var array 
         */
        public $validaion_values;
        public $errors = array();
        
        /**
         * Class Constructor. Defines the args for the extions class
         *
         * @since       1.0.0
         * @access      public
         * @param       array $sections Panel sections.
         * @param       array $args Class constructor arguments.
         * @param       array $extra_tabs Extra panel tabs.
         * @return      void
         */
        public function __construct($parent)
        {
            
            $this->parent = $parent;
            $this->extension_url = trailingslashit(WP_PLUGIN_URL).trailingslashit(plugin_basename(__DIR__));
            
            $upl_dir              = wp_upload_dir();
            $dir                  = $upl_dir["basedir"];
            $dir_url              = $upl_dir["baseurl"];
            $this->upload_dir     = $dir . "/fonts/";
            $this->upload_dir_url = $dir_url . "/fonts/";
            
            $this->field_name = 'custom_font';
            
            self::$theInstance = $this;
             
            $this->includeClases();
            
            add_filter('redux/' . $this->parent->args['opt_name'] . '/field/class/' . $this->field_name, array(
                $this,
                'overload_field_path'
            )); // Adds the local field
            add_filter("redux/validate/{$this->parent->args['opt_name']}/before_validation", array(
                $this,
                "valid"
            ));
            add_filter("redux/validate/{$this->parent->args['opt_name']}/class/font_load", array(
                $this,
                $this->validate_class
            ));
            $this->parent->outputCSS .= Custom_Font_Validator::generateFrontFontFace();
            add_filter("redux/{$this->parent->args['opt_name']}/field/typography/custom_fonts", array(
                $this,
                "add_custom_font"
            ));
            add_action("redux/options/{$this->parent->args['opt_name']}/import", array(
                $this,
                'import'
            ));
            
            add_action('wp_enqueue_scripts', array(
                $this,
                'buzzblogpro_typekit_enqueue'
            ));
            
            $this->add_font_section();
            
            add_action('redux/page/buzzblogpro_options/enqueue', array(
                $this,
                'addAndOverridePanelCSS'
            ));
			add_action( 'wp_ajax_nopriv_typekit_flush', array(
                $this,'typekit_flush'  ));
			add_action( 'wp_ajax_typekit_flush', array(
                $this,'typekit_flush'  ));
			
        }
	
		
public function typekit_flush() {
	global $wpdb;  
	$wpdb->query( "DELETE FROM $wpdb->options WHERE option_name LIKE 'buzzblogpro_typekit_%%'" ); 
	echo esc_html__( 'Font kits synchronized', 'buzzblogpro' );
	die();
}
        public function addAndOverridePanelCSS()
        {
		
            wp_deregister_script('redux-field-typography-js');
            wp_register_script('redux-field-typography-js', $this->extension_url . 'custom_font/field_typography.js', array(
                'jquery',
                'wp-color-picker',
                'select2-js',
                'redux-js'
            ), time(), true);
            wp_enqueue_style('redux-field-typography-js');
            
        }
        
        
        
        
        public function import($name)
        {
            $components_dir = dirname(__FILE__) . "/validator/";
            require_once $components_dir . "font_load" . ".php";
            $parent = $this->parent;
            $name   = $this->field_name;
            $list   = isset($this->parent->options[$name]) ? $this->parent->options[$name] : array();
            foreach ($list as $font_key => $font) {
                $id    = isset($font["attachment_id"]) ? $font["attachment_id"] : "";
                $field = array(
                    "id" => $id
                );
                new Redux_Validation_font_load($parent, $field, $font, $current = "");
            }
            return true;
        }
        
        public function add_custom_font()
        {

            //print_r($this->parent->options);
            $fonts_arr = array();
			$weights = array();
            if (isset($this->parent->options[$this->field_name])) {
                $fonts_arr = $this->parent->options[$this->field_name];
            }
            $local_fonts  = Custom_Font_Validator::instance()->getLocalFonts();
            $fonts_result = array();
            $fonts        = array();
            //            print_r($local_fonts);
                if (is_array($fonts_arr) || is_object($fonts_arr)) {
                
                foreach ($fonts_arr as $font_key => $font_value) {
                    $id = $font_value["attachment_id"];
                    if (!empty($local_fonts) && !is_string($local_fonts)) {
                        foreach ($local_fonts as $local_fonts_key => $local_fonts_value) {
                            if ($local_fonts_value["id"] == $id) {
                                $fonts_result[$local_fonts_key] = $local_fonts_key;
                                break;
                            }
                        }
                    }
                }
            }
            unset($fonts_arr);
            unset($local_fonts);
            //            print_r($fonts_result);
            $result = "";
            
            $mainoptions = get_option('buzzblogpro_options');
            $token       = empty($mainoptions['buzzblogpro_typekit_fonts_token']) ? '' : $mainoptions['buzzblogpro_typekit_fonts_token'];
            $kit         = empty($mainoptions['buzzblogpro_typekit_fonts_kit']) ? '' : $mainoptions['buzzblogpro_typekit_fonts_kit'];
            
            if ($token && $kit) {
                
                $data = wp_cache_get('buzzblogpro_typekit_fonts_kit_cache');
                
                if (!$data) {
                    $typekit = new Buzzblogpro_Typekit_Api();
                    
                    $data = $typekit->get($kit, $token);
                    
                    wp_cache_set('buzzblogpro_typekit_fonts_kit_cache', $data, 'buzzblogpro', 1);
                }
                
                if ($data && isset($data['kit']['families']) && $data['kit']['families']) {
                    
                    foreach ($data['kit']['families'] as $family) {
                        
                        // Loop variations.
                        if ($family['variations']) {
                            foreach ($family['variations'] as $variant) {
                                $var_format    = buzzblogpro_typekit_font_convert_format($variant);
                                $id            = $family['css_names']['0'];
                                $family_weight = isset($var_format['weight']) ? $var_format['weight'] : 'normal';
                                $family_style  = isset($var_format['style']) ? $var_format['style'] : 'normal';
                                //var_dump($var_format);
								
								
								$weights[] = array(
        'font' => $id,
		'weightstyle' => $family_weight.$family_style,
		'stylename' => $family_weight.' '.$family_style
		);
		
                                $fonts[$id] = $family['css_names']['0'];
                            }
                        }
                    }
                }
            }
            
            //}
			$my_json_str = json_encode($weights);
			$weightsToPass = array(
        'weights' => $my_json_str
    );
	
            wp_localize_script('redux-field-typography-js', 'customFonts', 
                        $weightsToPass
                    );
            $resultss = array_merge($fonts_result, $fonts);
            if (!empty($resultss)) {
                $result = array(
                    "Custom fonts" => $resultss
                );
            }
            
            
            
            $result = empty($result) ? array() : $result;
            
            return $result;
        }
        
        public function getParent()
        {
            return $this->parent;
        }
        
        public function valid($ar1, $arr2 = "")
        {
            $this->validaion_values = isset($ar1[$this->field_name]) ? $ar1[$this->field_name] : '';
            return $ar1;
        }
        
        public function font_load($arr1 = "", $arr2 = "")
        {
            $dir = Redux_Helpers::cleanFilePath(dirname(__FILE__));
            $dir .= "/validator/{$this->validate_class}.php";
            //            print_r($dir);
            return $dir;
        }
        
        /**
         * 
         * @return self
         */
        public static function getInstance()
        {
            return self::$theInstance;
        }
        
        private function includeClases()
        {
            $components_dir = dirname(__FILE__) . "/components/";
            require_once $components_dir . "ttf_info" . ".php";
            require_once $components_dir . "custom_font_validator" . ".php";
            require_once $components_dir . "mimetype" . ".php";
            
            require_once $components_dir . 'typekit/helpers/helper-typekit-fonts.php';
            require_once $components_dir . 'typekit/helpers/helper-typekit-fonts-api.php';
        }
        
        // Forces the use of the embeded field path vs what the core typically would use    
        public function overload_field_path($field)
        {
            
            return dirname(__FILE__) . '/' . $this->field_name . '/field_' . $this->field_name . '.php';
        }
        
        function add_font_section()
        {
		
		
            $data_kit    = array();
            $mainoptions = get_option('buzzblogpro_options');
            $token       = empty($mainoptions['buzzblogpro_typekit_fonts_token']) ? '' : $mainoptions['buzzblogpro_typekit_fonts_token'];
			 
            if ($token) {
                
                $typekit = new Buzzblogpro_Typekit_Api();
                
                $typekit_data = $typekit->get(null, $token);
                
                if ($typekit_data && isset($typekit_data['kits']) && $typekit_data['kits']) {
                    foreach ($typekit_data['kits'] as $item):
                        $kitsy = $typekit->get($item['id'], $token);
                        $data_kit[$kitsy['kit']['id']] = esc_html($kitsy['kit']['name']);
                    endforeach;
                }
            } else {
                $data_kit[] = "-No kits selected-";
            }
            
            
            // Checks to see if section was set in config of redux.
            for ($n = 0; $n <= count($this->parent->sections); $n++) {
                if (isset($this->parent->sections[$n]['id']) && $this->parent->sections[$n]['id'] == 'custom_font') {
                    return;
                }
            }
            
            
            
            $this->parent->sections[] = array(
                'title' => esc_html__('Custom fonts', 'buzzblogpro'),
                'icon' => 'dashicons dashicons-editor-customchar',
                'icon' => 'el-icon-website',
                'fields' => array(
								array(
       'id' => 'section-typekit',
       'type' => 'section',
       'title' => esc_html__('Adobe Fonts (Typekit)', 'buzzblogpro'),
       'indent' => false
   ),
                    array(
                        'id' => 'buzzblogpro_typekit_fonts_token',
                        'type' => 'text',
                        'title' => esc_html__('Token', 'buzzblogpro'),
							   'desc' => wp_kses(sprintf(__('1. Log in to your %s?<br>2. To get your API key, go to link %s<br>3. Copy your "Token" under the "API tokens" label.<br>4. If you don\'t see your Web projects, click %s link', 'buzzblogpro'), '<a href="https://fonts.adobe.com/" target="_blank">Adobe Fonts account</a>', '<a href="https://fonts.adobe.com/account/tokens" target="_blank">https://fonts.adobe.com/account/tokens</a>', '<a href="#" id="typekit_flush_cache" class="typekit-flush-button">Synchronize</a>'), wp_kses_allowed_html('post')),
                        'default' => ''
                    ),
                    array(
                        'id' => 'buzzblogpro_typekit_fonts_kit',
                        'type' => 'select',
                        'title' => esc_html__('Web projects', 'buzzblogpro'),
                        'options' => $data_kit,
						'required' => array( 
    array('buzzblogpro_typekit_fonts_token','!=','') 
),
                       
                    ),
															 array(
                'id'       => 'buzzblogpro_typekit_method',
                'type'     => 'button_set',
                'title'    => esc_html__( 'Loading method', 'buzzblogpro' ),
										'required' => array( 
    array('buzzblogpro_typekit_fonts_token','!=','') 
),
                'options'  => array(
              'normal' => esc_html__( 'Normal', 'buzzblogpro' ),
              'async' => esc_html__( 'Asynchronous', 'buzzblogpro' )
                ),
                'default'  => 'normal'
            ),
			array(
       'id' => 'section-custom-font',
       'type' => 'section',
       'title' => esc_html__('Custom web font', 'buzzblogpro'),
       'indent' => false 
   ),
                    array(
                        'type' => 'custom_font',
                        'id' => 'custom_font',
                        'validate' => 'font_load',
                        'title' => esc_html__('Font-face list:', 'buzzblogpro'),
                        'subtitle' => esc_html__('Upload .zip archive with font-face files.', 'buzzblogpro') . '<br>(<a target="_blank" href="https://www.web-font-generator.com/">' . esc_html__('Generate a web font package', 'buzzblogpro') . '</a>)',
                        'desc' => '<span style="color:#F09191">' . esc_html__('Note', 'buzzblogpro') . ':</span> ' . esc_html__('You have to download the font-face.zip archive.', 'buzzblogpro') . ' <br>' . __('Pay your attention, that the archive has to contain the font-face files itself, and not the subfolders', 'buzzblogpro') . '<br> (' . esc_html__('E.g.: font-face.zip/your-font-face.ttf, font-face.zip/your-font-face.eot, font-face.zip/your-font-face.woff etc', 'buzzblogpro') . ')'
                    )
                )
            );
        }
        

        public function buzzblogpro_typekit_enqueue()
        {
            $mainoptions = get_option('buzzblogpro_options');
            $token       = empty($mainoptions['buzzblogpro_typekit_fonts_token']) ? '' : $mainoptions['buzzblogpro_typekit_fonts_token'];
            $kit         = empty($mainoptions['buzzblogpro_typekit_fonts_kit']) ? '' : $mainoptions['buzzblogpro_typekit_fonts_kit'];
            $method =  empty($mainoptions['buzzblogpro_typekit_method']) ? 'normal' : $mainoptions['buzzblogpro_typekit_method'];
			
            if ($token && $kit) {
                if ('async' === $method) {
                    wp_enqueue_script('buzzblogpro-typekit', plugin_dir_url(__FILE__) . 'components/typekit/public/js/public-buzzblogpro-typekit.js', array(
                        'jquery'
                    ), '1.0', true);
                    
                    wp_localize_script('buzzblogpro-typekit', 'buzzblogpro_typekit', array(
                        'kit' => $kit
                    ));
                } else {
                    wp_enqueue_style('buzzblogpro-typekit', sprintf('https://use.typekit.net/%s.css', $kit), array(), '1.0', 'all');
                }
            }
        }
        
    }
    
    // class
} // if